@@ -14,6 +14,7 @@ from zou.app.services.exception import (
     WrongParameterException,
 )
 from zou.app.services import genesis_service
+from zou.app import config
 
 
 class BaseModelsResource(Resource):
@@ -185,8 +186,9 @@ class BaseModelsResource(Resource):
             self.check_create_permissions(data)
             self.check_creation_integrity(data)
             data = self.update_data(data)
-            if self.model.__tablename__ == 'project':
-                genesis_service.create_project(data=data)
+            if config.ENABLE_GENESIS:
+                if self.model.__tablename__ == 'project':
+                    genesis_service.create_project(data=data)
             instance = self.model.create(**data)
             instance_dict = self.post_creation(instance)
             self.emit_create_event(instance_dict)
@@ -304,8 +306,9 @@ class BaseModelResource(Resource):
                 )
             self.instance = self.get_model_or_404(instance_id)
             instance_dict = self.instance.serialize()
-            if self.model.__tablename__ == 'project':
-                genesis_service.project_rename(data=data,instance_dict=instance_dict)
+            if config.ENABLE_GENESIS:
+                if self.model.__tablename__ == 'project':
+                    genesis_service.project_rename(data=data,instance_dict=instance_dict)
             self.check_update_permissions(instance_dict, data)
             self.pre_update(instance_dict, data)
             data = self.update_data(data, instance_id)
