@@ -20,6 +20,8 @@ from werkzeug.exceptions import NotFound
 
 from .base import BaseModelResource, BaseModelsResource
 
+from zou.app import config
+
 
 class EntityEventMixin(object):
     def emit_event(self, event_name, entity_dict):
@@ -98,7 +100,8 @@ class EntityResource(BaseModelResource, EntityEventMixin):
         try:
             data = self.get_arguments()
             entity = self.get_model_or_404(instance_id)
-            genesis_service.rename_asset_task_file(data=data, entity=entity)
+            if config.ENABLE_GENESIS:
+                genesis_service.rename_asset_task_file(data=data, entity=entity)
             self.check_update_permissions(entity.serialize(), data)
 
             extra_data = copy.copy(entity.data) or {}
