@@ -14,6 +14,8 @@ from zou.app.utils import permissions, fields
 
 from .base import BaseModelResource, BaseModelsResource
 
+from zou.app import config
+
 
 class ProjectsResource(BaseModelsResource):
     def __init__(self):
@@ -89,10 +91,12 @@ class ProjectResource(BaseModelResource):
         else:
             self.check_delete_permissions(project_dict)
             if args["force"] == True:
-                genesis_service.archive_project(project_dict['name'])
+                if config.ENABLE_GENESIS:
+                    genesis_service.archive_project(project_dict['name'])
                 deletion_service.remove_project(instance_id)
             else:
-                genesis_service.archive_project(project_dict['name'])
+                if config.ENABLE_GENESIS:
+                    genesis_service.archive_project(project_dict['name'])
                 project.delete()
             self.post_delete(project_dict)
             return "", 204
