@@ -7,6 +7,7 @@ from flask_jwt_extended import jwt_required
 from zou.app import config
 from zou.app.mixin import ArgsMixin
 from zou.app.services import (
+    genesis_service,
     persons_service,
     tasks_service,
     time_spents_service,
@@ -38,6 +39,11 @@ class NewPersonResource(Resource):
                 "limit": config.USER_LIMIT,
             }, 400
         else:
+            #TODO create ldap user
+            # if config['ENABLE_GENESIS']:
+            #     desktop_login=genesis_service.create_ldap_user(data["first_name"], data["last_name"], data["email"], password='default')
+            #     print(desktop_login, '----create ldap user-----------')
+
             person = persons_service.create_person(
                 data["email"],
                 auth.encrypt_password("default"),
