@@ -10,23 +10,26 @@ from zou.app import config
 from zou.app.mixin import ArgsMixin
 from zou.app.stores import file_store
 from zou.app.services import (
+    assets_service,
     deletion_service,
     entities_service,
     files_service,
     names_service,
     persons_service,
     projects_service,
+    preview_files_service,
     shots_service,
     tasks_service,
     user_service,
 )
+from zou.app.stores import queue_store
 from zou.app.utils import (
     fs,
     events,
-    movie_utils,
     permissions,
     thumbnail as thumbnail_utils,
 )
+from zou.utils import movie
 
 
 ALLOWED_PICTURE_EXTENSION = [".png", ".jpg", ".jpeg", ".PNG", ".JPG", ".JPEG"]
@@ -45,35 +48,44 @@ ALLOWED_MOVIE_EXTENSION = [
     ".MKV",
 ]
 ALLOWED_FILE_EXTENSION = [
-    ".obj",
-    ".pdf",
-    ".ma",
-    ".mb",
-    ".ai",
-    ".rar",
-    ".gif",
-    ".zip",
-    ".blend",
-    ".OBJ",
-    ".PDF",
-    ".MA",
-    ".MB",
-    ".AI",
-    ".RAR",
-    ".ZIP",
-    ".BLEND",
-    ".comp",
-    ".psd",
-    ".hip",
-    ".exr",
-    ".COMP",
-    ".PSD",
-    ".HIP",
     ".ae",
+    ".ai",
+    ".blend",
+    ".comp",
+    ".exr",
+    ".fbx",
     ".fla",
     ".flv",
+    ".gif",
+    ".hip",
+    ".ma",
+    ".mb",
+    ".obj",
+    ".pdf",
+    ".psd",
+    ".rar",
+    ".svg",
     ".swf",
+    ".zip",
+    ".AE",
+    ".AI",
+    ".BLEND",
+    ".COMP",
     ".EXR",
+    ".FBX",
+    ".FLA",
+    ".FLV",
+    ".GIF",
+    ".HIP",
+    ".MA",
+    ".MB",
+    ".OBJ",
+    ".PDF",
+    ".PSD",
+    ".RAR",
+    ".SVG",
+    ".SWF",
+    ".ZIP",
 ]
 
 
@@ -94,11 +106,14 @@ def send_standard_file(
     )
 
 
-def send_movie_file(preview_file_id, as_attachment=False):
+def send_movie_file(preview_file_id, as_attachment=False, lowdef=False):
+    folder = "previews"
+    if lowdef:
+        folder = "lowdef"
     return send_storage_file(
         file_store.get_local_movie_path,
         file_store.open_movie,
-        "previews",
+        folder,
         preview_file_id,
         "mp4",
         mimetype="video/mp4",
@@ -151,26 +166,10 @@ def send_storage_file(
         )
     except IOError as e:
         current_app.logger.error(e)
-        return (
-            {
-                "error": True,
-                "message": "File not found for: %s %s"
-                % (prefix, preview_file_id),
-            },
-            404,
-        )
-    except FileNotFound:
-        return (
-            {
-                "error": True,
-                "message": "File not found for: %s %s"
-                % (prefix, preview_file_id),
-            },
-            404,
-        )
+        raise FileNotFound
 
 
-class CreatePreviewFilePictureResource(Resource):
+class CreatePreviewFilePictureResource(Resource, ArgsMixin):
     """
     Main resource to add a preview. It stores the preview file and generates
     three picture files matching preview when it's possible: a square thumbnail,
@@ -193,9 +192,13 @@ class CreatePreviewFilePictureResource(Resource):
 
         if extension in ALLOWED_PICTURE_EXTENSION:
             self.save_picture_preview(instance_id, uploaded_file)
-            preview_file = files_service.update_preview_file(
+            preview_file = preview_files_service.update_preview_file(
                 instance_id,
-                {"extension": "png", "original_name": original_file_name},
+                {
+                    "extension": "png",
+                    "original_name": original_file_name,
+                    "status": "ready",
+                },
             )
             self.emit_app_preview_event(instance_id)
             return preview_file, 201
@@ -208,7 +211,7 @@ class CreatePreviewFilePictureResource(Resource):
                 current_app.logger.error("Normalization failed.")
                 deletion_service.remove_preview_file_by_id(instance_id)
                 abort(400, "Normalization failed.")
-            preview_file = files_service.update_preview_file(
+            preview_file = preview_files_service.update_preview_file(
                 instance_id,
                 {"extension": "mp4", "original_name": original_file_name},
             )
@@ -217,11 +220,12 @@ class CreatePreviewFilePictureResource(Resource):
 
         elif extension in ALLOWED_FILE_EXTENSION:
             self.save_file_preview(instance_id, uploaded_file, extension)
-            preview_file = files_service.update_preview_file(
+            preview_file = preview_files_service.update_preview_file(
                 instance_id,
                 {
                     "extension": extension[1:],
                     "original_name": original_file_name,
+                    "status": "ready",
                 },
             )
             self.emit_app_preview_event(instance_id)
@@ -243,32 +247,31 @@ class CreatePreviewFilePictureResource(Resource):
         original_tmp_path = thumbnail_utils.save_file(
             tmp_folder, instance_id, uploaded_file
         )
-        return self.save_variants(original_tmp_path, instance_id)
+        return preview_files_service.save_variants(
+            instance_id, original_tmp_path
+        )
 
-    def save_movie_preview(self, instance_id, uploaded_file):
+    def save_movie_preview(self, preview_file_id, uploaded_file):
         """
         Get uploaded movie, normalize it then build thumbnails then save
         everything in the file storage.
         """
+        no_job = self.get_no_job()
         tmp_folder = current_app.config["TMP_DIR"]
-        uploaded_movie_path = movie_utils.save_file(
-            tmp_folder, instance_id, uploaded_file
+        uploaded_movie_path = movie.save_file(
+            tmp_folder, preview_file_id, uploaded_file
         )
-
-        project = files_service.get_project_from_preview_file(instance_id)
-        fps = shots_service.get_preview_fps(project)
-        (width, height) = shots_service.get_preview_dimensions(project)
-        normalized_movie_path = movie_utils.normalize_movie(
-            uploaded_movie_path, fps=fps, width=width, height=height
-        )
-        file_store.add_movie("previews", instance_id, normalized_movie_path)
-        original_tmp_path = movie_utils.generate_thumbnail(
-            normalized_movie_path
-        )
-
-        os.remove(uploaded_movie_path)
-        os.remove(normalized_movie_path)
-        return self.save_variants(original_tmp_path, instance_id)
+        if config.ENABLE_JOB_QUEUE and not no_job:
+            queue_store.job_queue.enqueue(
+                preview_files_service.prepare_and_store_movie,
+                args=(preview_file_id, uploaded_movie_path),
+                job_timeout=600,
+            )
+        else:
+            preview_files_service.prepare_and_store_movie(
+                preview_file_id, uploaded_movie_path
+            )
+        return preview_file_id
 
     def save_file_preview(self, instance_id, uploaded_file, extension):
         """
@@ -282,20 +285,6 @@ class CreatePreviewFilePictureResource(Resource):
         os.remove(file_path)
         return file_path
 
-    def save_variants(self, original_tmp_path, instance_id):
-        """
-        Build variants of a picture file and save them in the main storage.
-        """
-        variants = thumbnail_utils.generate_preview_variants(
-            original_tmp_path, instance_id
-        )
-        variants.append(("original", original_tmp_path))
-        for (name, path) in variants:
-            file_store.add_picture(name, instance_id, path)
-            os.remove(path)
-
-        return variants
-
     def emit_app_preview_event(self, preview_file_id):
         """
         Emit an event, each time a preview is added.
@@ -304,17 +293,12 @@ class CreatePreviewFilePictureResource(Resource):
         comment = tasks_service.get_comment_by_preview_file_id(preview_file_id)
         task = tasks_service.get_task(preview_file["task_id"])
         comment_id = None
-        events.emit(
-            "preview-file:update", {"preview_file_id": preview_file["id"]},
-            project_id=task["project_id"]
-        )
-
         if comment is not None:
             comment_id = comment["id"]
             events.emit(
                 "comment:update",
                 {"comment_id": comment_id},
-                project_id=task["project_id"]
+                project_id=task["project_id"],
             )
             events.emit(
                 "preview-file:add-file",
@@ -324,8 +308,9 @@ class CreatePreviewFilePictureResource(Resource):
                     "preview_file_id": preview_file["id"],
                     "revision": preview_file["revision"],
                     "extension": preview_file["extension"],
+                    "status": preview_file["status"],
                 },
-                project_id=task["project_id"]
+                project_id=task["project_id"],
             )
 
     def is_allowed(self, preview_file_id):
@@ -380,10 +365,34 @@ class PreviewFileMovieResource(Resource):
         try:
             return send_movie_file(instance_id)
         except FileNotFound:
-            current_app.logger.error("Movie file was not found for: %s" % instance_id)
+            current_app.logger.error(
+                "Movie file was not found for: %s" % instance_id
+            )
             abort(404)
 
 
+class PreviewFileLowMovieResource(PreviewFileMovieResource):
+    """
+    Allow to download a lowdef movie preview.
+    """
+
+    @jwt_required
+    def get(self, instance_id):
+        if not self.is_allowed(instance_id):
+            abort(403)
+
+        try:
+            return send_movie_file(instance_id, lowdef=True)
+        except Exception as e:
+            try:
+                return send_movie_file(instance_id)
+            except FileNotFound:
+                current_app.logger.error(
+                    "Movie file was not found for: %s" % instance_id
+                )
+                abort(404)
+
+
 class PreviewFileMovieDownloadResource(PreviewFileMovieResource):
     """
     Allow to download a movie preview.
@@ -397,7 +406,9 @@ class PreviewFileMovieDownloadResource(PreviewFileMovieResource):
         try:
             return send_movie_file(instance_id, as_attachment=True)
         except FileNotFound:
-            current_app.logger.error("Movie file was not found for: %s" % instance_id)
+            current_app.logger.error(
+                "Movie file was not found for: %s" % instance_id
+            )
             abort(404)
 
 
@@ -443,7 +454,9 @@ class PreviewFileResource(Resource):
                 return send_standard_file(instance_id, extension)
 
         except FileNotFound:
-            current_app.logger.error("Non-movie file was not found for: %s" % instance_id)
+            current_app.logger.error(
+                "Non-movie file was not found for: %s" % instance_id
+            )
             abort(404)
 
 
@@ -478,7 +491,9 @@ class PreviewFileDownloadResource(PreviewFileResource):
                     instance_id, extension, as_attachment=True
                 )
         except FileNotFound:
-            current_app.logger.error("Standard file was not found for: %s" % instance_id)
+            current_app.logger.error(
+                "Standard file was not found for: %s" % instance_id
+            )
             abort(404)
 
 
@@ -518,7 +533,9 @@ class BasePreviewPictureResource(Resource):
         try:
             return send_picture_file(self.picture_type, instance_id)
         except FileNotFound:
-            current_app.logger.error("Picture file was not found for: %s" % instance_id)
+            current_app.logger.error(
+                "Picture file was not found for: %s" % instance_id
+            )
             abort(404)
 
 
@@ -575,8 +592,7 @@ class BaseCreatePictureResource(Resource):
     def emit_event(self, instance_id):
         model_name = self.data_type[:-1]
         events.emit(
-            "%s:set-thumbnail" % model_name,
-            {"%s_id" % model_name: instance_id}
+            "%s:set-thumbnail" % model_name, {"%s_id" % model_name: instance_id}
         )
 
     @jwt_required
@@ -630,10 +646,14 @@ class BasePictureResource(Resource):
         try:
             return send_picture_file("thumbnails", instance_id)
         except FileNotFound:
-            current_app.logger.error("Thumbnail file was not found for: %s" % instance_id)
+            current_app.logger.error(
+                "Thumbnail file was not found for: %s" % instance_id
+            )
             abort(404)
         except IOError:
-            current_app.logger.error("Thumbnail file was not found for: %s" % instance_id)
+            current_app.logger.error(
+                "Thumbnail file was not found for: %s" % instance_id
+            )
             abort(404)
 
 
@@ -745,9 +765,12 @@ class SetMainPreviewResource(Resource):
         task = tasks_service.get_task(preview_file["task_id"])
         user_service.check_project_access(task["project_id"])
         user_service.check_entity_access(task["entity_id"])
-        return entities_service.update_entity_preview(
+        asset = entities_service.update_entity_preview(
             task["entity_id"], preview_file_id
         )
+        assets_service.clear_asset_cache(asset["id"])
+        shots_service.clear_shot_cache(asset["id"])
+        return asset
 
 
 class UpdatePreviewPositionResource(Resource, ArgsMixin):
@@ -763,6 +786,6 @@ class UpdatePreviewPositionResource(Resource, ArgsMixin):
         preview_file = files_service.get_preview_file(preview_file_id)
         task = tasks_service.get_task(preview_file["task_id"])
         user_service.check_manager_project_access(task["project_id"])
-        return tasks_service.update_preview_file_position(
+        return preview_files_service.update_preview_file_position(
             preview_file_id, args["position"]
         )
