@@ -25,6 +25,7 @@ from zou.app.services.exception import (
     AssetTypeNotFoundException,
 )
 
+from zou.app import config
 
 def clear_asset_cache(asset_id):
     cache.cache.delete_memoized(get_asset, asset_id)
@@ -531,7 +532,8 @@ def remove_asset(asset_id, force=False):
             deletion_service.remove_task(task.id, force=True)
             tasks_service.clear_task_cache(str(task.id))
             #TODO delete asset
-            genesis_service.delete_task_file(task=task.serialize(), entity_type='asset')
+            if config.ENABLE_GENESIS:
+                genesis_service.delete_task_file(task=task.serialize(), entity_type='asset')
         asset.delete()
         clear_asset_cache(str(asset_id))
         events.emit(
