@@ -1,12 +1,18 @@
+import base64
+import json
+import logging
 import os
-from operator import itemgetter
-from slugify import slugify
+import textwrap
+import time
 
+from operator import itemgetter
+from pathlib import Path
 from shutil import copyfile
 from zipfile import ZipFile
 
 from flask import current_app
 from flask_mail import Message
+from slugify import slugify
 from sqlalchemy import or_
 
 from zou.app import config
@@ -18,7 +24,7 @@ from zou.app.models.preview_file import PreviewFile
 from zou.app.models.task import Task
 from zou.app.models.task_type import TaskType
 
-from zou.app.utils import fields, movie_utils, events
+from zou.app.utils import fields, events
 from zou.app.utils import query as query_utils
 
 from zou.app.services import (
@@ -26,6 +32,7 @@ from zou.app.services import (
     base_service,
     entities_service,
     files_service,
+    preview_files_service,
     projects_service,
     shots_service,
     tasks_service,
@@ -37,49 +44,65 @@ from zou.app.services.exception import (
     PlaylistNotFoundException,
 )
 
+from zou.utils import movie
 
-def all_playlists_for_project(project_id, for_client=False):
+logger = logging.getLogger(__name__)
+
+
+def all_playlists_for_project(
+    project_id, for_client=False, page=1, sort_by="updated_at"
+):
     """
     Return all playlists created for given project.
     """
     result = []
+    query = Playlist.query.filter(Playlist.project_id == project_id)
     if for_client:
-        playlists = Playlist.get_all_by(project_id=project_id, for_client=True)
-    else:
-        playlists = Playlist.get_all_by(project_id=project_id)
+        query = query.filter(Playlist.for_client)
+
+    query = query_utils.apply_sort_by(Playlist, query, sort_by)
+    if page < 1:
+        page = 1
+    limit = 20
+    offset = (page - 1) * limit
+    query = query.limit(limit)
+    query = query.offset(offset)
+    playlists = query.all()
     for playlist in playlists:
         playlist_dict = build_playlist_dict(playlist)
         result.append(playlist_dict)
     return result
 
 
-def all_playlists_for_episode(project_id, episode_id, for_client=False):
+def all_playlists_for_episode(
+    project_id, episode_id, for_client=False, sort_by="updated_at"
+):
     """
     Return all playlists created for given episode.
     """
     result = []
     query = Playlist.query
     if for_client:
-        query = query.filter(Playlist.for_client == True)
+        query = query.filter(Playlist.for_client)
 
     if episode_id == "main":
-        query = query \
-            .filter(Playlist.episode_id == None) \
-            .filter(Playlist.project_id == project_id) \
+        query = (
+            query.filter(Playlist.episode_id == None)
+            .filter(Playlist.project_id == project_id)
             .filter(
-                or_(
-                    Playlist.is_for_all == None,
-                    Playlist.is_for_all == False
-                )
+                or_(Playlist.is_for_all == None, Playlist.is_for_all == False)
             )
+        )
     elif episode_id == "all":
-        query = query \
-            .filter(Playlist.episode_id == None) \
-            .filter(Playlist.project_id == project_id) \
+        query = (
+            query.filter(Playlist.episode_id == None)
+            .filter(Playlist.project_id == project_id)
             .filter(Playlist.is_for_all == True)
+        )
     else:
         query = query.filter(Playlist.episode_id == episode_id)
 
+    query = query_utils.apply_sort_by(Playlist, query, sort_by)
     playlists = query.all()
     for playlist in playlists:
         playlist_dict = build_playlist_dict(playlist)
@@ -103,10 +126,12 @@ def build_playlist_dict(playlist):
 
 def get_first_shot_preview_file_id(playlist):
     first_shot_preview_file_id = None
-    if playlist.shots is not None \
-       and len(playlist.shots) > 0 \
-       and type(playlist.shots) == list \
-       and "preview_file_id" in playlist.shots[0]:
+    if (
+        playlist.shots is not None
+        and len(playlist.shots) > 0
+        and type(playlist.shots) == list
+        and "preview_file_id" in playlist.shots[0]
+    ):
         first_shot_preview_file_id = playlist.shots[0]["preview_file_id"]
     return first_shot_preview_file_id
 
@@ -119,8 +144,7 @@ def get_playlist_with_preview_file_revisions(playlist_id):
     playlist = get_playlist_raw(playlist_id)
     playlist_dict = playlist.serialize()
     playlist_dict = _add_build_job_infos_to_playlist_dict(
-        playlist,
-        playlist_dict
+        playlist, playlist_dict
     )
 
     if playlist_dict["shots"] is None:
@@ -135,6 +159,7 @@ def get_playlist_with_preview_file_revisions(playlist_id):
             if preview_file is not None:
                 shot["preview_file_id"] = preview_file["id"]
                 shot["preview_file_extension"] = preview_file["extension"]
+                shot["preview_file_status"] = preview_file["status"]
                 shot["preview_file_annotations"] = preview_file["annotations"]
                 shot["preview_file_task_id"] = preview_file["task_id"]
                 shot["preview_file_previews"] = preview_file["previews"]
@@ -154,6 +179,8 @@ def _add_build_job_infos_to_playlist_dict(playlist, playlist_dict):
 
 def set_preview_files_for_entities(playlist_dict):
     """
+    Retrieve all preview files related to entities listed in given playlist.
+    Add to each entity a dict with task as keys and preview list as values.
     """
     entity_ids = []
     for entity in playlist_dict["shots"]:
@@ -168,8 +195,7 @@ def set_preview_files_for_entities(playlist_dict):
     preview_file_map = {}
 
     preview_files = (
-        PreviewFile.query
-        .join(Task)
+        PreviewFile.query.join(Task)
         .join(TaskType)
         .filter(Task.entity_id.in_(entity_ids))
         .order_by(TaskType.priority.desc())
@@ -201,6 +227,7 @@ def set_preview_files_for_entities(playlist_dict):
             "id": preview_file_id,
             "revision": preview_file.revision,
             "extension": preview_file.extension,
+            "status": str(preview_file.status),
             "annotations": preview_file.annotations,
             "created_at": fields.serialize_value(preview_file.created_at),
             "task_id": task_id,
@@ -230,17 +257,17 @@ def get_preview_files_for_entity(entity_id):
     """
     previews = {}
     query = (
-        Task.query
-        .filter_by(entity_id=entity_id)
+        Task.query.filter_by(entity_id=entity_id)
         .add_columns(
             PreviewFile.id,
             PreviewFile.revision,
             PreviewFile.position,
             PreviewFile.original_name,
             PreviewFile.extension,
+            PreviewFile.status,
             PreviewFile.annotations,
             PreviewFile.created_at,
-            PreviewFile.task_id
+            PreviewFile.task_id,
         )
         .join(PreviewFile)
         .join(TaskType)
@@ -258,24 +285,30 @@ def get_preview_files_for_entity(entity_id):
         preview_file_position,
         preview_file_original_name,
         preview_file_extension,
+        preview_file_status,
         preview_file_annotations,
         preview_file_created_at,
-        preview_file_task_id
+        preview_file_task_id,
     ) in query.all():
         task_id = str(task.id)
         if task_id not in task_previews:
             task_previews[task_id] = []
-        task_previews[task_id].append(fields.serialize_dict({
-            "id": preview_file_id,
-            "revision": preview_file_revision,
-            "position": preview_file_position,
-            "original_name": preview_file_original_name,
-            "extension": preview_file_extension,
-            "annotations": preview_file_annotations,
-            "created_at": preview_file_created_at,
-            "task_id": task_id,
-            "task_type_id": str(task.task_type_id),
-        }))
+        task_previews[task_id].append(
+            fields.serialize_dict(
+                {
+                    "id": preview_file_id,
+                    "revision": preview_file_revision,
+                    "position": preview_file_position,
+                    "original_name": preview_file_original_name,
+                    "extension": preview_file_extension,
+                    "status": preview_file_status,
+                    "annotations": preview_file_annotations,
+                    "created_at": preview_file_created_at,
+                    "task_id": task_id,
+                    "task_type_id": str(task.task_type_id),
+                }
+            )
+        )
 
     for task_id in task_previews.keys():
         preview_files = task_previews[task_id]
@@ -289,10 +322,11 @@ def get_preview_files_for_entity(entity_id):
                     "revision": preview_file["revision"],
                     "original_name": preview_file["original_name"],
                     "extension": preview_file["extension"],
+                    "status": preview_file["status"],
                     "annotations": preview_file["annotations"],
                     "previews": preview_file["previews"],
                     "created_at": preview_file["created_at"],
-                    "task_id": preview_file["task_id"]
+                    "task_id": preview_file["task_id"],
                 }
                 for preview_file in preview_files
             ]  # Do not add too much field to avoid building too big responses
@@ -334,69 +368,93 @@ def get_playlist(playlist_id):
     return get_playlist_raw(playlist_id).serialize()
 
 
-def retrieve_playlist_tmp_files(playlist, only_movies=False):
+def playlist_previews(shots, only_movies=False):
     """
-    Retrieve all files for a given playlist into the temporary folder.
+    Retrieve all preview id and extension for the given shots.
     """
     preview_files = []
-    for entity in playlist["shots"]:
+    for entity in shots:
         if (
-            "preview_file_id" in entity and
-            entity["preview_file_id"] is not None and
-            len(entity["preview_file_id"]) > 0
+            "preview_file_id" in entity
+            and entity["preview_file_id"] is not None
+            and len(entity["preview_file_id"]) > 0
         ):
             preview_file = files_service.get_preview_file(
                 entity["preview_file_id"]
             )
             if preview_file is not None and (
-                (only_movies and preview_file["extension"] == "mp4") or
-                not only_movies
+                (only_movies and preview_file["extension"] == "mp4")
+                or not only_movies
             ):
                 preview_files.append(preview_file)
 
+    return [
+        {"id": x["id"], "extension": x["extension"]}
+        for x in preview_files
+    ]
+
+
+def retrieve_playlist_tmp_files(preview_files, full=False):
+    """
+    Retrieve all files for a given playlist into the temporary folder.
+    """
     file_paths = []
     for preview_file in preview_files:
-        prefix = "original"
-        if preview_file["extension"] == "mp4":
-            get_path_func = file_store.get_local_movie_path
-            open_func = file_store.open_movie
-            prefix = "previews"
-        elif preview_file["extension"] == "png":
-            get_path_func = file_store.get_local_picture_path
-            open_func = file_store.open_picture
+        if full:
+            preview_file = files_service.get_preview_file(preview_file["id"])
+            sub_preview_files = \
+                preview_files_service.get_preview_files_for_revision(
+                    preview_file["task_id"], preview_file["revision"]
+                )
+            for preview_file in sub_preview_files:
+                tmp_file_path, file_name = \
+                    retrieve_playlist_tmp_file(preview_file)
+                file_paths.append((tmp_file_path, file_name))
         else:
-            get_path_func = file_store.get_local_file_path
-            open_func = file_store.open_file
-
-        if config.FS_BACKEND == "local":
-            file_path = get_path_func(
-                prefix, preview_file["id"]
-            )
-        else:
-            file_path = os.path.join(
-                config.TMP_DIR,
-                "cache-previews-%s.%s" % (
-                    preview_file["id"],
-                    preview_file["extension"]
-                ),
-            )
-            if not os.path.exists(file_path) or os.path.getsize(file_path) == 0:
-                with open(file_path, "wb") as tmp_file:
-                    for chunk in open_func(prefix, preview_file["id"]):
-                        tmp_file.write(chunk)
-
-        file_name = names_service.get_preview_file_name(preview_file["id"])
-        tmp_file_path = os.path.join(config.TMP_DIR, file_name)
-        copyfile(file_path, tmp_file_path)
-        file_paths.append((tmp_file_path, file_name))
+            tmp_file_path, file_name = retrieve_playlist_tmp_file(preview_file)
+            file_paths.append((tmp_file_path, file_name))
     return file_paths
 
 
+def retrieve_playlist_tmp_file(preview_file):
+    if preview_file["extension"] == "mp4":
+        get_path_func = file_store.get_local_movie_path
+        open_func = file_store.open_movie
+        prefix = "previews"
+    elif preview_file["extension"] == "png":
+        get_path_func = file_store.get_local_picture_path
+        open_func = file_store.open_picture
+        prefix = "original"
+    else:
+        get_path_func = file_store.get_local_file_path
+        open_func = file_store.open_file
+        prefix = "previews"
+
+    if config.FS_BACKEND == "local":
+        file_path = get_path_func(prefix, preview_file["id"])
+    else:
+        file_path = os.path.join(
+            config.TMP_DIR,
+            "cache-previews-%s.%s"
+            % (preview_file["id"], preview_file["extension"]),
+        )
+        if not os.path.exists(file_path) or os.path.getsize(file_path) == 0:
+            with open(file_path, "wb") as tmp_file:
+                for chunk in open_func(prefix, preview_file["id"]):
+                    tmp_file.write(chunk)
+    file_name = names_service.get_preview_file_name(preview_file["id"])
+    tmp_file_path = os.path.join(config.TMP_DIR, file_name)
+    copyfile(file_path, tmp_file_path)
+    return tmp_file_path, file_name
+
+
 def build_playlist_zip_file(playlist):
     """
     Build a zip for all files for a given playlist into the temporary folder.
     """
-    tmp_file_paths = retrieve_playlist_tmp_files(playlist)
+    previews = playlist_previews(playlist["shots"])
+    tmp_file_paths = retrieve_playlist_tmp_files(previews, full=True)
+
     zip_file_path = get_playlist_zip_file_path(playlist)
     if os.path.exists(zip_file_path):
         os.remove(zip_file_path)
@@ -406,35 +464,192 @@ def build_playlist_zip_file(playlist):
     return zip_file_path
 
 
-def build_playlist_movie_file(playlist, app=None):
+def build_playlist_movie_file(playlist, shots, params, remote):
     """
     Build a movie for all files for a given playlist into the temporary folder.
     """
     job = start_build_job(playlist)
-    project = projects_service.get_project(playlist["project_id"])
-    tmp_file_paths = retrieve_playlist_tmp_files(playlist, only_movies=True)
-    movie_file_path = get_playlist_movie_file_path(playlist, job)
-    (width, height) = shots_service.get_preview_dimensions(project)
-    fps = shots_service.get_preview_fps(project)
+    success = False
+    try:
+        previews = playlist_previews(shots, only_movies=True)
+        movie_file_path = get_playlist_movie_file_path(job)
+        tmp_file_paths = retrieve_playlist_tmp_files(previews)
 
-    result = movie_utils.build_playlist_movie(
-        tmp_file_paths, movie_file_path, width, height, fps
-    )
-    if result["success"] == True:
-        if os.path.exists(movie_file_path):
-            file_store.add_movie("playlists", job["id"], movie_file_path)
-        else:
-            if app is not None:
-                current_app.logger.error("No playlist was created")
-            result["success"] = False
-            result["message"] = "No playlist was created"
+        # First, try using concat demuxer
+        success = _run_concatenation(
+            playlist,
+            job,
+            tmp_file_paths,
+            movie_file_path,
+            params,
+            movie.concat_demuxer,
+        )
+
+        # Try again using concat filter
+        if not success:
+            if not remote:
+                success = _run_concatenation(
+                    playlist,
+                    job,
+                    tmp_file_paths,
+                    movie_file_path,
+                    params,
+                    movie.concat_filter,
+                )
+            else:
+                from zou.app import app
+
+                with app.app_context():
+                    try:
+                        _execute_nomad_job(
+                            job, previews, params, movie_file_path
+                        )
+                        success = True
+                    except Exception as exc:
+                        current_app.logger.error(exc)
+                        success = False
+
+    # exception will by logged by rq
+    finally:
+        job = end_build_job(playlist, job, success)
+
+    if not success:
+        raise Exception("Failure while building playlist %r" % playlist["id"])
 
-    elif app is not None:
-        current_app.logger.error(result["message"])
-    end_build_job(playlist, job, result)
     return job
 
 
+def _run_concatenation(
+    playlist, job, tmp_file_paths, movie_file_path, params, mode
+):
+    success = False
+    try:
+        result = movie.build_playlist_movie(
+            mode, tmp_file_paths, movie_file_path, **params._asdict()
+        )
+        if result["success"] and os.path.exists(movie_file_path):
+            file_store.add_movie("playlists", job["id"], movie_file_path)
+            success = True
+        if result.get("message"):
+            current_app.logger.error(result["message"])
+    except Exception:
+        logger.error(
+            "Unable to build playlist %r using %s",
+            (playlist["id"], mode.__qualname__),
+            exc_info=1,
+        )
+    return success
+
+
+def _execute_nomad_job(job, previews, params, movie_file_path):
+    import nomad
+    import zlib
+    import json
+
+    preview_ids = [
+        preview["id"] for preview in previews if preview["extension"] == "mp4"
+    ]
+    input_bytes = zlib.compress(bytes(json.dumps(preview_ids), "utf-8"))
+    input_string = base64.b64encode(input_bytes).decode("ascii")
+    bucket_prefix = config.FS_BUCKET_PREFIX
+    params = {
+        "version": "1",
+        "bucket_prefix": bucket_prefix,
+        "output_filename": Path(movie_file_path).name,
+        "output_key": file_store.make_key("playlists", job["id"]),
+        "input": input_string,
+        "width": params.width,
+        "height": params.height,
+        "fps": params.fps,
+        "FS_BACKEND": config.FS_BACKEND,
+    }
+    # Add object storage information
+    if config.FS_BACKEND == "s3":
+        params.update(
+            {
+                "S3_ENDPOINT": config.FS_S3_ENDPOINT,
+                "AWS_DEFAULT_REGION": config.FS_S3_REGION,
+                "AWS_ACCESS_KEY_ID": config.FS_S3_ACCESS_KEY,
+                "AWS_SECRET_ACCESS_KEY": config.FS_S3_SECRET_KEY,
+            }
+        )
+    elif config.FS_BACKEND == "swift":
+        params.update(
+            {
+                "OS_USERNAME": config.FS_SWIFT_USER,
+                "OS_PASSWORD": config.FS_SWIFT_KEY,
+                "OS_AUTH_URL": config.FS_SWIFT_AUTHURL,
+                "OS_TENANT_NAME": config.FS_SWIFT_TENANT_NAME,
+                "OS_REGION_NAME": config.FS_SWIFT_REGION_NAME,
+            }
+        )
+
+    # don't use 'app.config' because the webapp doesn't use this variable,
+    # only the rq worker does.
+    nomad_job = os.getenv("JOB_QUEUE_NOMAD_PLAYLIST_JOB", "zou-playlist")
+    nomad_host = os.getenv("JOB_QUEUE_NOMAD_HOST", "zou-nomad-01.zou")
+    data = json.dumps(params).encode("utf-8")
+    payload = base64.b64encode(data).decode("utf-8")
+    ncli = nomad.Nomad(host=nomad_host, timeout=5)
+
+    response = ncli.job.dispatch_job(nomad_job, payload=payload)
+    nomad_jobid = response["DispatchedJobID"]
+
+    while True:
+        summary = ncli.job.get_summary(nomad_jobid)
+        task_group = list(summary["Summary"])[0]
+        status = summary["Summary"][task_group]
+        if status["Failed"] != 0 or status["Lost"] != 0:
+            logger.debug("Nomad job %r failed: %r", nomad_jobid, status)
+            out, err = _get_nomad_job_logs(ncli, nomad_jobid)
+            out = textwrap.indent(out, "\t")
+            err = textwrap.indent(err, "\t")
+            raise Exception(
+                "Job %s is 'Failed' or 'Lost':\nStatus: "
+                "%s\nerr:\n%s\nout:\n%s" % (nomad_jobid, status, err, out)
+            )
+        if status["Complete"] == 1:
+            logger.debug("Nomad job %r: complete", nomad_jobid)
+            break
+        # there isn't a timeout here but python rq jobs have a timeout. Nomad
+        # jobs have a timeout too.
+        time.sleep(1)
+
+    # fetch movie from object storage
+    with open(movie_file_path, "wb") as movie_file:
+        for chunk in file_store.open_movie("playlists", job["id"]):
+            movie_file.write(chunk)
+
+
+def _get_nomad_job_logs(ncli, nomad_jobid):
+    allocations = ncli.job.get_allocations(nomad_jobid)
+    last = max(
+        [(alloc["CreateIndex"], idx) for idx, alloc in enumerate(allocations)]
+    )[1]
+    alloc_id = allocations[last]["ID"]
+    # logs aren't available when the task isn't started
+    task = allocations[last]["TaskStates"]["zou-playlist"]
+    if not task["StartedAt"]:
+        out = "\n".join([x["DisplayMessage"] for x in task["Events"]])
+        err = ""
+    else:
+        err = ncli.client.stream_logs.stream(
+            alloc_id, "zou-playlist", "stderr")
+        out = ncli.client.stream_logs.stream(
+            alloc_id, "zou-playlist", "stdout")
+        if err:
+            try:
+                err_json = json.loads(err).get("Data", "")
+                err_json = base64.b64decode(err).decode("utf-8")
+            except Exception:
+                err_json = err
+            err = err_json
+        if out:
+            out = json.loads(out).get("Data", "")
+            out = base64.b64decode(out).decode("utf-8")
+    return out.rstrip(), err.rstrip()
+
+
 def start_build_job(playlist):
     """
     clients that a new job is running.
@@ -450,21 +665,23 @@ def start_build_job(playlist):
             "playlist_id": playlist["id"],
             "created_at": fields.serialize_value(job.created_at),
         },
-        project_id=playlist["project_id"]
+        project_id=playlist["project_id"],
     )
     return job.serialize()
 
 
-def end_build_job(playlist, job, result):
+def end_build_job(playlist, job, success):
     """
     Register in database that a build is finished. Emits an event to notify
     clients that the build is done.
     """
-    build_job = BuildJob.get(job["id"])
-    build_job.end()
-    status = "succeeded"
-    if not result["success"]:
+    if success:
+        status = "succeeded"
+    else:
         status = "failed"
+
+    build_job = BuildJob.get(job["id"])
+    build_job.end(status=status)
     events.emit(
         "build-job:update",
         {
@@ -472,42 +689,39 @@ def end_build_job(playlist, job, result):
             "playlist_id": playlist["id"],
             "status": status,
         },
-        project_id=playlist["project_id"]
+        project_id=playlist["project_id"],
     )
     return build_job.serialize()
 
 
-def build_playlist_job(playlist, email):
+def build_playlist_job(playlist, shots, params, email, remote):
     """
-    Build playlist file (concatenate all mnovie previews). This function is
+    Build playlist file (concatenate all movie previews). This function is
     aimed at being runned as a job in a job queue.
     """
     from zou.app import app, mail
 
     with app.app_context():
-        job = None
-        try:
-            job = build_playlist_movie_file(playlist)
-        except:
-            if job is not None:
-                end_build_job(playlist, job)
-            raise
+        job = build_playlist_movie_file(playlist, shots, params, remote)
 
-        message_text = """
+        # Just in case, since rq jobs which encounter an error raise an
+        # exception in order to be flagged as failed.
+        if job["status"] == "succeeded":
+            message_text = """
 Your playlist %s is available at:
 https://%s/api/data/playlists/%s/jobs/%s/build/mp4
 """ % (
-            playlist["name"],
-            config.DOMAIN_NAME,
-            playlist["id"],
-            job["id"],
-        )
-        message = Message(
-            body=message_text,
-            subject="CGWire playlist download",
-            recipients=[email],
-        )
-        mail.send(message)
+                playlist["name"],
+                config.DOMAIN_NAME,
+                playlist["id"],
+                job["id"],
+            )
+            message = Message(
+                body=message_text,
+                subject="CGWire playlist download",
+                recipients=[email],
+            )
+            mail.send(message)
 
 
 def get_playlist_file_name(playlist):
@@ -522,7 +736,7 @@ def get_playlist_file_name(playlist):
     return slugify(attachment_filename)
 
 
-def get_playlist_movie_file_path(playlist, build_job):
+def get_playlist_movie_file_path(build_job):
     """
     Build file path for the movie file matching given playlist.
     """
@@ -567,7 +781,7 @@ def remove_playlist(playlist_id):
     events.emit(
         "playlist:delete",
         {"playlist_id": playlist_dict["id"]},
-        project_id=playlist_dict["project_id"]
+        project_id=playlist_dict["project_id"],
     )
     return playlist_dict
 
@@ -578,12 +792,12 @@ def remove_build_job(playlist, build_job_id):
     hard drive.
     """
     job = BuildJob.get(build_job_id)
-    movie_file_path = get_playlist_movie_file_path(playlist, job.serialize())
+    movie_file_path = get_playlist_movie_file_path(job.serialize())
     if os.path.exists(movie_file_path):
         os.remove(movie_file_path)
     try:
         file_store.remove_movie("playlists", build_job_id)
-    except:
+    except Exception:
         current_app.logger.error(
             "Playlist file can't be deleted: %s" % build_job_id
         )
@@ -591,7 +805,7 @@ def remove_build_job(playlist, build_job_id):
     events.emit(
         "build-job:delete",
         {"build_job_id": build_job_id, "playlist_id": playlist["id"]},
-        project_id=playlist["project_id"]
+        project_id=playlist["project_id"],
     )
     return movie_file_path
 
@@ -608,7 +822,7 @@ def get_build_jobs_for_project(project_id):
 
 def get_playlists_for_project(project_id, page=0):
     """
-    Return all time spents for given project.
+    Return all playlists for given project.
     """
     query = Playlist.query.filter(Playlist.project_id == project_id)
     return query_utils.get_paginated_results(query, page, relations=True)
@@ -626,9 +840,9 @@ def generate_temp_playlist(task_ids):
         entities.append(entity)
     if len(entities) > 0:
         if "sequence_name" in entities[0]:
-            return sorted(entities, key=itemgetter('sequence_name', 'name'))
+            return sorted(entities, key=itemgetter("sequence_name", "name"))
         else:
-            return sorted(entities, key=itemgetter('asset_type_name', 'name'))
+            return sorted(entities, key=itemgetter("asset_type_name", "name"))
     else:
         return []
 
@@ -649,12 +863,15 @@ def generate_playlisted_entity_from_task(task_id):
     preview_files = get_preview_files_for_entity(entity["id"])
     if task_type_id in preview_files and len(preview_files[task_type_id]) > 0:
         preview_file = preview_files[task_type_id][0]
-        playlisted_entity.update({
-            "preview_file_id": preview_file["id"],
-            "preview_file_extension": preview_file["extension"],
-            "preview_file_annotations": preview_file["annotations"],
-            "preview_file_previews": preview_file["previews"]
-        })
+        playlisted_entity.update(
+            {
+                "preview_file_id": preview_file["id"],
+                "preview_file_extension": preview_file["extension"],
+                "preview_file_status": preview_file["status"],
+                "preview_file_annotations": preview_file["annotations"],
+                "preview_file_previews": preview_file["previews"],
+            }
+        )
     playlisted_entity["preview_files"] = preview_files
     return playlisted_entity
 
@@ -668,7 +885,7 @@ def get_base_shot_for_playlist(entity, task_id):
         "preview_file_task_id": task_id,
         "sequence_id": sequence["id"],
         "sequence_name": sequence["name"],
-        "parent_name": sequence["name"]
+        "parent_name": sequence["name"],
     }
     return playlisted_entity
 
@@ -682,7 +899,7 @@ def get_base_asset_for_playlist(entity, task_id):
         "preview_file_task_id": task_id,
         "asset_type_id": asset_type["id"],
         "asset_type_name": asset_type["name"],
-        "parent_name": asset_type["name"]
+        "parent_name": asset_type["name"],
     }
     return playlisted_entity
 
@@ -709,6 +926,7 @@ def _get_playlist_preview_file_list(preview_files):
             "id": str(preview_file.id),
             "revision": preview_file.revision,
             "extension": preview_file.extension,
+            "status": str(preview_file.status),
             "annotations": preview_file.annotations,
             "created_at": fields.serialize_value(preview_file.created_at),
             "task_id": str(preview_file.task_id),
