@@ -28,6 +28,8 @@ from zou.app.services.exception import (
     WrongIdFormatException,
 )
 
+from zou.app import config
+
 
 def clear_shot_cache(shot_id):
     cache.cache.delete_memoized(get_shot, shot_id)
@@ -804,7 +806,8 @@ def remove_shot(shot_id, force=False):
         tasks = Task.query.filter_by(entity_id=shot_id).all()
         for task in tasks:
             #TODO delete shot
-            genesis_service.delete_task_file(task=task.serialize(), entity_type='shot')
+            if config.ENABLE_GENESIS:
+                genesis_service.delete_task_file(task=task.serialize(), entity_type='shot')
             deletion_service.remove_task(task.id, force=True)
             tasks_service.clear_task_cache(str(task.id))
 
