@@ -50,6 +50,8 @@ from zou.app.services import (
     genesis_service
 )
 
+from zou.app import config
+
 
 def clear_task_status_cache(task_status_id):
     cache.cache.delete_memoized(get_task_statuses)
@@ -878,7 +880,8 @@ def create_tasks(task_type, entities):
                 assigner_id=current_user_id,
                 assignees=[],
             )
-            genesis_service.create_task_file(entity=entity, task=task, task_type=task_type, project_id=entity["project_id"])
+            if config.ENABLE_GENESIS:
+                genesis_service.create_task_file(task=task, task_type=task_type, project_id=entity["project_id"])
             tasks.append(task)
     Task.commit()
 
@@ -1102,12 +1105,13 @@ def clear_assignation(task_id):
     """
     Clear task assignation and emit a *task:unassign* event.
     """
-    # TODO clear assignation of task
-    print('access removed')
     task = get_task_raw(task_id)
-    print(task)
     project_id = str(task.project_id)
     assignees = [person.serialize() for person in task.assignees]
+    # TODO clear assignation of task
+    if config.ENABLE_GENESIS:
+        for person in task.assignees:
+            genesis_service.grant_file_access(task, person, project_id, permission='none')
     task.update({"assignees": []})
     clear_task_cache(task_id)
     task_dict = task.serialize()
@@ -1131,7 +1135,8 @@ def assign_task(task_id, person_id):
 
     task.assignees.append(person)
     #TODO assign task
-    # genesis_service.grant_file_access(task, person, project_id)
+    if config.ENABLE_GENESIS:
+        genesis_service.grant_file_access(task, person, project_id, permission='rw')
     task.save()
     task_dict = task.serialize()
     events.emit(
